### Hive NetworkX
Hive plots in Python.

#### Dependencies:
Compatible for Python 2 and 3.

	pandas
	numpy

#### Install:
```
# "Stable" release (still developmental)
pip install hive_networkx
# Current release
pip install git+https://github.com/jolespin/hive_networkx
```
